@@ -26,7 +26,7 @@ extern wchar_t *** __MINGW_IMP_SYMBOL(__winitenv);
 #define __winitenv (* __MINGW_IMP_SYMBOL(__winitenv))
 #endif
 
-#ifndef __initenv
+#if !defined(__initenv) && !defined(__arm__)
 extern char *** __MINGW_IMP_SYMBOL(__initenv);
 #define __initenv (* __MINGW_IMP_SYMBOL(__initenv))
 #endif
@@ -170,7 +170,7 @@ int WinMainCRTStartup (void);
 int WinMainCRTStartup (void)
 {
   int ret = 255;
-#ifdef __SEH__
+#if defined(__SEH__) && !defined(__clang__)
   asm ("\t.l_startw:\n"
     "\t.seh_handler __C_specific_handler, @except\n"
     "\t.seh_handlerdata\n"
@@ -182,7 +182,7 @@ int WinMainCRTStartup (void)
   mingw_app_type = 1;
   __security_init_cookie ();
   ret = __tmainCRTStartup ();
-#ifdef __SEH__
+#if defined(__SEH__) && !defined(__clang__)
   asm ("\tnop\n"
     "\t.l_endw: nop\n");
 #endif
@@ -198,7 +198,7 @@ int __mingw_init_ehandler (void);
 int mainCRTStartup (void)
 {
   int ret = 255;
-#ifdef __SEH__
+#if defined(__SEH__) && !defined(__clang__)
   asm ("\t.l_start:\n"
     "\t.seh_handler __C_specific_handler, @except\n"
     "\t.seh_handlerdata\n"
@@ -210,7 +210,7 @@ int mainCRTStartup (void)
   mingw_app_type = 0;
   __security_init_cookie ();
   ret = __tmainCRTStartup ();
-#ifdef __SEH__
+#if defined(__SEH__) && !defined(__clang__)
   asm ("\tnop\n"
     "\t.l_end: nop\n");
 #endif
@@ -226,7 +226,7 @@ __tmainCRTStartup (void)
   WINBOOL inDoubleQuote = FALSE;
   memset (&StartupInfo, 0, sizeof (STARTUPINFO));
 
-#ifndef _WIN64
+#if defined(__i386__) || defined(_X86_)
   /* We need to make sure that this function is build with frame-pointer
      and that we align the stack to 16 bytes for the sake of SSE ops in main
      or in functions inlined into main.  */
@@ -235,7 +235,7 @@ __tmainCRTStartup (void)
 #ifdef __GNUC__
   asm  __volatile__  ("andl $-16, %%esp" : : : "%esp");
 #endif
-#endif
+#endif /* defined(__i386__) || defined(_X86_) */
 
   if (mingw_app_type)
     GetStartupInfo (&StartupInfo);
@@ -328,7 +328,9 @@ __tmainCRTStartup (void)
        gcc inserts this call automatically for a function called main, but not for wmain.  */
     mainret = wmain (argc, argv, envp);
 #else
+#ifndef __arm__
     __initenv = envp;
+#endif
     mainret = main (argc, argv, envp);
 #endif
     if (!managedapp)
