@@ -8,8 +8,11 @@
 long lrintl (long double x) 
 {
   long retval = 0l;
-  __asm__ __volatile__							      \
-    ("fistpl %0"  : "=m" (retval) : "t" (x) : "st");				      \
+#if defined(_AMD64_) || defined(__x86_64__) || defined(_X86_) || defined(__i386__)
+  __asm__ __volatile__ ("fistpl %0"  : "=m" (retval) : "t" (x) : "st");
+#elif defined(__arm__) || defined(_ARM_)
+    retval = lrint(x);
+#endif
   return retval;
 }
 
