@@ -7,6 +7,10 @@
 
 long double rintl (long double x) {
   long double retval = 0.0L;
+#if defined(_AMD64_) || defined(__x86_64__) || defined(_X86_) || defined(__i386__)
   __asm__ __volatile__ ("frndint;": "=t" (retval) : "0" (x));
+#elif defined(__arm__) || defined(_ARM_)
+    retval = rint(x);
+#endif
   return retval;
 }
