@@ -25,15 +25,14 @@
 #ifndef __WINE_D3DTYPES_H
 #define __WINE_D3DTYPES_H
 
-#include <_mingw_dxhelper.h>
-
-#ifndef __WINESRC__
-# include <windows.h>
-#endif
-
+#include <windows.h>
 #include <float.h>
 #include <ddraw.h>
 
+#ifdef __i386__
+#include <pshpack4.h>
+#endif
+
 #define D3DVALP(val, prec)      ((float)(val))
 #define D3DVAL(val)             ((float)(val))
 #define D3DDivide(a, b)         (float)((double) (a) / (double) (b))
@@ -76,9 +75,9 @@ typedef LONG D3DFIXED;
 #define D3DENUMRET_CANCEL                        DDENUMRET_CANCEL
 #define D3DENUMRET_OK                            DDENUMRET_OK
 
-typedef HRESULT (CALLBACK *LPD3DVALIDATECALLBACK)(LPVOID lpUserArg, DWORD dwOffset);
-typedef HRESULT (CALLBACK *LPD3DENUMTEXTUREFORMATSCALLBACK)(LPDDSURFACEDESC lpDdsd, LPVOID lpContext);
-typedef HRESULT (CALLBACK *LPD3DENUMPIXELFORMATSCALLBACK)(LPDDPIXELFORMAT lpDDPixFmt, LPVOID lpContext);
+typedef HRESULT (CALLBACK *LPD3DVALIDATECALLBACK)(void *ctx, DWORD offset);
+typedef HRESULT (CALLBACK *LPD3DENUMTEXTUREFORMATSCALLBACK)(DDSURFACEDESC *surface_desc, void *ctx);
+typedef HRESULT (CALLBACK *LPD3DENUMPIXELFORMATSCALLBACK)(DDPIXELFORMAT *format, void *ctx);
 
 #ifndef DX_SHARED_DEFINES
 
@@ -140,15 +139,10 @@ public:
   friend D3DVALUE DotProduct(const _D3DVECTOR& v1, const _D3DVECTOR& v2);
   friend _D3DVECTOR CrossProduct(const _D3DVECTOR& v1, const _D3DVECTOR& v2);
 #endif
-} D3DVECTOR;
+} D3DVECTOR,*LPD3DVECTOR;
 #define D3DVECTOR_DEFINED
 #endif
 
-#ifndef LPD3DVECTOR_DEFINED
-typedef D3DVECTOR *LPD3DVECTOR;
-#define LPD3DVECTOR_DEFINED
-#endif
-
 #define DX_SHARED_DEFINES
 #endif /* DX_SHARED_DEFINES */
 
@@ -343,9 +337,9 @@ typedef struct _D3DMATRIX {
 
     /* This is different from MS, but avoids anonymous structs. */
     D3DVALUE &operator () (int r, int c)
-	{ return ((D3DVALUE [4][4])&_11)[r][c]; }
+	{ return (&_11)[r*4 + c]; }
     const D3DVALUE &operator() (int r, int c) const
-	{ return ((const D3DVALUE [4][4])&_11)[r][c]; }
+	{ return (&_11)[r*4 + c]; }
 #endif
 } D3DMATRIX, *LPD3DMATRIX;
 
@@ -478,11 +472,11 @@ typedef struct _D3DVIEWPORT7 {
 
 typedef struct _D3DTRANSFORMDATA {
   DWORD           dwSize;
-  LPVOID          lpIn;
+  void            *lpIn;
   DWORD           dwInSize;
-  LPVOID          lpOut;
+  void            *lpOut;
   DWORD           dwOutSize;
-  LPD3DHVERTEX    lpHOut;
+  D3DHVERTEX      *lpHOut;
   DWORD           dwClip;
   DWORD           dwClipIntersection;
   DWORD           dwClipUnion;
@@ -607,9 +601,9 @@ typedef struct _D3DLIGHT2 {
 
 typedef struct _D3DLIGHTDATA {
   DWORD                dwSize;
-  LPD3DLIGHTINGELEMENT lpIn;
+  D3DLIGHTINGELEMENT   *lpIn;
   DWORD                dwInSize;
-  LPD3DTLVERTEX        lpOut;
+  D3DTLVERTEX          *lpOut;
   DWORD                dwOutSize;
 } D3DLIGHTDATA, *LPD3DLIGHTDATA;
 
@@ -966,14 +960,14 @@ typedef enum _D3DMATERIALCOLORSOURCE
 } D3DMATERIALCOLORSOURCE;
 
 #define D3DRENDERSTATE_BLENDENABLE      D3DRENDERSTATE_ALPHABLENDENABLE
-#define D3DRENDERSTATE_WRAPBIAS                 128UL
-#define D3DWRAP_U   0x00000001L
-#define D3DWRAP_V   0x00000002L
+#define D3DRENDERSTATE_WRAPBIAS         __MSABI_LONG(128U)
+#define D3DWRAP_U   __MSABI_LONG(0x00000001)
+#define D3DWRAP_V   __MSABI_LONG(0x00000002)
 
-#define D3DWRAPCOORD_0   0x00000001L
-#define D3DWRAPCOORD_1   0x00000002L
-#define D3DWRAPCOORD_2   0x00000004L
-#define D3DWRAPCOORD_3   0x00000008L
+#define D3DWRAPCOORD_0   __MSABI_LONG(0x00000001)
+#define D3DWRAPCOORD_1   __MSABI_LONG(0x00000002)
+#define D3DWRAPCOORD_2   __MSABI_LONG(0x00000004)
+#define D3DWRAPCOORD_3   __MSABI_LONG(0x00000008)
 
 #define D3DRENDERSTATE_STIPPLEPATTERN(y) (D3DRENDERSTATE_STIPPLEPATTERN00 + (y))
 
@@ -1008,13 +1002,13 @@ typedef struct _D3DPROCESSVERTICES {
   DWORD dwReserved;
 } D3DPROCESSVERTICES, *LPD3DPROCESSVERTICES;
 
-#define D3DPROCESSVERTICES_TRANSFORMLIGHT       0x00000000L
-#define D3DPROCESSVERTICES_TRANSFORM            0x00000001L
-#define D3DPROCESSVERTICES_COPY                 0x00000002L
-#define D3DPROCESSVERTICES_OPMASK               0x00000007L
+#define D3DPROCESSVERTICES_TRANSFORMLIGHT       __MSABI_LONG(0x00000000)
+#define D3DPROCESSVERTICES_TRANSFORM            __MSABI_LONG(0x00000001)
+#define D3DPROCESSVERTICES_COPY                 __MSABI_LONG(0x00000002)
+#define D3DPROCESSVERTICES_OPMASK               __MSABI_LONG(0x00000007)
 
-#define D3DPROCESSVERTICES_UPDATEEXTENTS        0x00000008L
-#define D3DPROCESSVERTICES_NOCOLOR              0x00000010L
+#define D3DPROCESSVERTICES_UPDATEEXTENTS        __MSABI_LONG(0x00000008)
+#define D3DPROCESSVERTICES_NOCOLOR              __MSABI_LONG(0x00000010)
 
 typedef enum _D3DTEXTURESTAGESTATETYPE
 {
@@ -1120,14 +1114,14 @@ typedef enum _D3DTEXTUREMIPFILTER
     D3DTFP_FORCE_DWORD  = 0x7fffffff
 } D3DTEXTUREMIPFILTER;
 
-#define D3DTRIFLAG_START                        0x00000000L
+#define D3DTRIFLAG_START                        __MSABI_LONG(0x00000000)
 #define D3DTRIFLAG_STARTFLAT(len) (len)
-#define D3DTRIFLAG_ODD                          0x0000001eL
-#define D3DTRIFLAG_EVEN                         0x0000001fL
+#define D3DTRIFLAG_ODD                          __MSABI_LONG(0x0000001e)
+#define D3DTRIFLAG_EVEN                         __MSABI_LONG(0x0000001f)
 
-#define D3DTRIFLAG_EDGEENABLE1                  0x00000100L
-#define D3DTRIFLAG_EDGEENABLE2                  0x00000200L
-#define D3DTRIFLAG_EDGEENABLE3                  0x00000400L
+#define D3DTRIFLAG_EDGEENABLE1                  __MSABI_LONG(0x00000100)
+#define D3DTRIFLAG_EDGEENABLE2                  __MSABI_LONG(0x00000200)
+#define D3DTRIFLAG_EDGEENABLE3                  __MSABI_LONG(0x00000400)
 #define D3DTRIFLAG_EDGEENABLETRIANGLE \
         (D3DTRIFLAG_EDGEENABLE1 | D3DTRIFLAG_EDGEENABLE2 | D3DTRIFLAG_EDGEENABLE3)
 
@@ -1171,7 +1165,7 @@ typedef struct _D3DPOINT {
 typedef struct _D3DBRANCH {
   DWORD dwMask;
   DWORD dwValue;
-  BOOL  bNegate;
+  WINBOOL  bNegate;
   DWORD dwOffset;
 } D3DBRANCH, *LPD3DBRANCH;
 
@@ -1181,8 +1175,8 @@ typedef struct _D3DSTATUS {
   D3DRECT drExtent;
 } D3DSTATUS, *LPD3DSTATUS;
 
-#define D3DSETSTATUS_STATUS   0x00000001L
-#define D3DSETSTATUS_EXTENTS  0x00000002L
+#define D3DSETSTATUS_STATUS   __MSABI_LONG(0x00000001)
+#define D3DSETSTATUS_EXTENTS  __MSABI_LONG(0x00000002)
 #define D3DSETSTATUS_ALL      (D3DSETSTATUS_STATUS | D3DSETSTATUS_EXTENTS)
 
 typedef struct _D3DCLIPSTATUS {
@@ -1193,9 +1187,9 @@ typedef struct _D3DCLIPSTATUS {
   float minz, maxz;
 } D3DCLIPSTATUS, *LPD3DCLIPSTATUS;
 
-#define D3DCLIPSTATUS_STATUS        0x00000001L
-#define D3DCLIPSTATUS_EXTENTS2      0x00000002L
-#define D3DCLIPSTATUS_EXTENTS3      0x00000004L
+#define D3DCLIPSTATUS_STATUS        __MSABI_LONG(0x00000001)
+#define D3DCLIPSTATUS_EXTENTS2      __MSABI_LONG(0x00000002)
+#define D3DCLIPSTATUS_EXTENTS3      __MSABI_LONG(0x00000004)
 
 typedef struct {
   DWORD        dwSize;
@@ -1206,8 +1200,8 @@ typedef struct {
   DWORD        dwVerticesProcessed;
 } D3DSTATS, *LPD3DSTATS;
 
-#define D3DEXECUTE_CLIPPED       0x00000001l
-#define D3DEXECUTE_UNCLIPPED     0x00000002l
+#define D3DEXECUTE_CLIPPED       __MSABI_LONG(0x00000001)
+#define D3DEXECUTE_UNCLIPPED     __MSABI_LONG(0x00000002)
 
 typedef struct _D3DEXECUTEDATA {
   DWORD     dwSize;
@@ -1230,10 +1224,10 @@ typedef struct _D3DVERTEXBUFFERDESC {
   DWORD dwNumVertices;
 } D3DVERTEXBUFFERDESC, *LPD3DVERTEXBUFFERDESC;
 
-#define D3DVBCAPS_SYSTEMMEMORY      0x00000800l
-#define D3DVBCAPS_WRITEONLY         0x00010000l
-#define D3DVBCAPS_OPTIMIZED         0x80000000l
-#define D3DVBCAPS_DONOTCLIP         0x00000001l
+#define D3DVBCAPS_SYSTEMMEMORY      __MSABI_LONG(0x00000800)
+#define D3DVBCAPS_WRITEONLY         __MSABI_LONG(0x00010000)
+#define D3DVBCAPS_OPTIMIZED         __MSABI_LONG(0x80000000)
+#define D3DVBCAPS_DONOTCLIP         __MSABI_LONG(0x00000001)
 
 #define D3DVOP_LIGHT       (1 << 10)
 #define D3DVOP_TRANSFORM   (1 << 0)
@@ -1280,9 +1274,10 @@ typedef struct _D3DVERTEXBUFFERDESC {
 #define D3DFVF_TLVERTEX ( D3DFVF_XYZRHW | D3DFVF_DIFFUSE | D3DFVF_SPECULAR | \
                           D3DFVF_TEX1 )
 
-typedef struct _D3DDP_PTRSTRIDE {
-  LPVOID lpvData;
-  DWORD  dwStride;
+typedef struct _D3DDP_PTRSTRIDE
+{
+  void *lpvData;
+  DWORD dwStride;
 } D3DDP_PTRSTRIDE;
 
 #define D3DDP_MAXTEXCOORD 8
@@ -1365,4 +1360,8 @@ typedef enum _D3DTEXTURETRANSFORMFLAGS {
 #define D3DFVF_TEXCOORDSIZE4(CoordIndex) (D3DFVF_TEXTUREFORMAT4 << (CoordIndex*2 + 16))
 #define D3DFVF_TEXCOORDSIZE1(CoordIndex) (D3DFVF_TEXTUREFORMAT1 << (CoordIndex*2 + 16))
 
+#ifdef __i386__
+#include <poppack.h>
+#endif
+
 #endif
