@@ -10,6 +10,7 @@
 #include <ipmib.h>
 #include <ipifcons.h>
 #include <udpmib.h>
+#include <tcpmib.h>
 
 #define IPRTRMGR_PID 10000
 
@@ -354,11 +355,6 @@ typedef struct _MIB_TCP6ROW_OWNER_MODULE {
 #define MIB_TCP_STATE_TIME_WAIT 11
 #define MIB_TCP_STATE_DELETE_TCB 12
 
-/* As I read msdn on Vista the defines above were moved into
-   typedef enum { MIB_..., } MIB_TCP_STATE;
-   We simply typedef it to int.  */
-typedef int MIB_TCP_STATE;
-
 typedef struct _MIB_TCPTABLE {
   DWORD dwNumEntries;
   MIB_TCPROW table[ANY_SIZE];
