@@ -18,8 +18,8 @@
 #ifndef __COMPAT_STRING_H
 #define __COMPAT_STRING_H
 
-#ifndef HAVE_STRLWER
-char *strlwr(char *s);
-#endif /* HAVE_STRLWER */
+#ifndef HAVE_STRLWR
+char *strlwr(char *);
+#endif /* HAVE_STRLWR */
 
 #endif /* __COMPAT_STRING_H */
