@@ -836,7 +836,7 @@ disassembleRetIntern (uint32_t pc, uint32_t *retpop, sAddresses *seen, sAddresse
       if (!sz || code == c_ill)
         {
           PRDEBUG(" %s = 0x08%x ILL (%u) at least one==%d\n",name,
-	 	  (unsigned int) pc, (unsigned int) sz,atleast_one[0]);
+		  (unsigned int) pc, (unsigned int) sz,atleast_one[0]);
 #if ENABLE_DEBUG == 1
       {
         unsigned char *ppc = (unsigned char *) map_va (pc);
@@ -1031,10 +1031,10 @@ redo_switch:
     PRDEBUG(" 0x%x illegal ", (unsigned int) b);
 #endif
     *aCode=c_ill; return 0;
-  case c_4: sz++;
-  case c_3: sz++;
+  case c_4: sz++;/* fallthru */
+  case c_3: sz++;/* fallthru */
   case c_lb:
-  case c_2: sz++;
+  case c_2: sz++;/* fallthru */
   case c_retn: case c_retf:
   case c_iret: case c_int3:
   case c_ad: case c_op:
@@ -1061,7 +1061,7 @@ redo_switch:
           p = (unsigned char *) map_va (pc + sz);
           if (!p) { *aCode=c_ill; return 0; }
 #if ENABLE_DEBUG == 1
-    enter_save_insn(lw,p[0]);
+	  enter_save_insn(lw,p[0]);
 #endif
           b&=~0x7; b|=(p[0]&7);
 	  sz+=1;
